@@ -87,6 +87,10 @@ module Rabbit
       end
 
       def compile(canvas, x, y, w, h)
+        compile_element(canvas, x, y, w, h)
+      end
+
+      def compile_element(canvas, x, y, w, h)
         @base_x, @base_y, @base_w, @base_h = x, y, w, h
         @px, @py, @pw, @ph = @x, @y, @w, @h
         x, y, w, h = setup_margin(x, y, w, h)
@@ -103,6 +107,8 @@ module Rabbit
       def compile_horizontal(canvas, x, y, w, h)
         if do_horizontal_centering?
           do_horizontal_centering(canvas, x, y, w, h)
+        else
+          reset_horizontal_centering(canvas, x, y, w, h)
         end
       end
 
@@ -278,7 +284,9 @@ module Rabbit
       end
 
       def horizontal_centering=(new_value)
-        dirty! if @horizontal_centering != new_value
+        if @horizontal_centering != new_value
+          dirty!
+        end
         @horizontal_centering = new_value
       end
 
@@ -290,6 +298,9 @@ module Rabbit
       def do_horizontal_centering(canvas, x, y, w, h)
       end
 
+      def reset_horizontal_centering(canvas, x, y, w, h)
+      end
+
       def previous_element
         sibling_element(-1)
       end
@@ -320,11 +331,10 @@ module Rabbit
 
       def inspect(verbose=false)
         if verbose
-          self_info = super()
+          super()
         else
-          self_info = "<#{self.class.name}>"
+          "<#{self.class.name}>"
         end
-        self_info
       end
 
       def clone
