@@ -9,7 +9,7 @@ module Rabbit
       attr_reader :original_width, :original_height
       attr_reader :first_line_width, :first_line_height
 
-      attr_writer :wrap_mode, :indent, :spacing
+      attr_writer :wrap_mode, :indent
 
       def initialize(*args, &block)
         super
@@ -34,6 +34,11 @@ module Rabbit
         @justify = new_value
       end
 
+      def spacing=(new_spacing)
+        dirty! if @spacing != new_spacing
+        @spacing = new_spacing
+      end
+
       def width
         if @width
           @width + @padding_left + @padding_right
@@ -49,7 +54,7 @@ module Rabbit
           nil
         end
       end
-      
+
       def compile(canvas, x, y, w, h)
         super
         text_compile(canvas, x, y, w, h)
@@ -75,7 +80,11 @@ module Rabbit
       def do_horizontal_centering(canvas, x, y, w, h)
         self.align = Pango::Layout::ALIGN_CENTER
       end
-     
+
+      def reset_horizontal_centering(canvas, x, y, w, h)
+        self.align = default_align if @align == Pango::Layout::ALIGN_CENTER
+      end
+
       def markuped_text
         markup(text)
       end
@@ -200,7 +209,7 @@ module Rabbit
         end
         layout.set_alignment(@align)
         layout.set_indent(@indent)
-        layout.set_spacing(@spacing)
+        layout.set_spacing(@spacing * Pango::SCALE)
         layout.justify = @justify
         layout.context_changed
       end
