@@ -69,7 +69,7 @@ module Rabbit
         w = original_width
         h = original_height
         pixbuf = Gdk::Pixbuf.new(Gdk::Pixbuf::COLORSPACE_RGB, true, 8, w, h)
-        page.render_to_pixbuf(0, 0, w, h, 1.0, 0, pixbuf)
+        page.render(0, 0, w, h, 1.0, 0, pixbuf)
         pixbuf
       end
     end
