@@ -6,7 +6,9 @@ require 'rabbit/parser/ext/image'
 require 'rabbit/parser/ext/enscript'
 require 'rabbit/parser/ext/tex'
 require 'rabbit/parser/ext/aafigure'
-require 'rabbit/parser/ext/anthy'
+require 'rabbit/parser/ext/blockdiag'
+require 'rabbit/parser/ext/coderay'
+require 'rabbit/parser/ext/emacs'
 require 'rabbit/parser/ext/entity'
 
 module Rabbit
@@ -262,8 +264,8 @@ module Rabbit
           lang = info ? info.downcase : nil
           result = nil
 
-          if lang and Ext::Enscript.check_availability(lang, @canvas.logger)
-            result = Ext::Enscript.highlight(lang, contents, @canvas.logger)
+          if lang
+            result = Ext::CodeRay.highlight(lang, contents, @canvas.logger)
           end
 
           if result
@@ -378,7 +380,7 @@ module Rabbit
             super(@private.pack(text, *rest))
           end
 
-          def lang(lang, text)
+          def lang(lang, text, *rest)
             super(lang, @private.pack(text, *rest))
           end
 
@@ -390,6 +392,14 @@ module Rabbit
             WaitTag.new
           end
 
+          def tag(name, text=nil, *rest)
+            if text
+              CustomTag.new(name, @private.pack(text, *rest))
+            else
+              CustomTag.new(name)
+            end
+          end
+
           class Private
             include Element
             def initialize(output)
@@ -445,21 +455,10 @@ module Rabbit
             end
           end
 
-          def anthy(source)
-            unless Ext::Anthy.available?
-              @output.canvas.logger.warn(_("Anthy isn't available"))
-              return nil
-            end
-
-            converted_source = Ext::Anthy.hiragana_to_kanji(source)
-            converted_source =
-              Ext::Escape.escape_meta_character(converted_source)
-            Paragraph.new(Text.new(converted_source))
-          end
-
           def LaTeX(source, props={})
             args = [@output.canvas, source]
             Ext::Image.make_image_from_file(*args) do |src_file_path|
+              props = Utils.stringify_hash_key(props)
               args = [src_file_path, props, @output.canvas]
               [Ext::TeX.make_image_by_LaTeX(*args), props]
             end
@@ -469,6 +468,7 @@ module Rabbit
           def mimeTeX(source, props={})
             args = [@output.canvas, source]
             Ext::Image.make_image_from_file(*args) do |src_file_path|
+              props = Utils.stringify_hash_key(props)
               args = [src_file_path, props, @output.canvas]
               [Ext::TeX.make_image_by_mimeTeX(*args), props]
             end
@@ -478,8 +478,36 @@ module Rabbit
           def aafigure(source, props={})
             args = [@output.canvas, source]
             Ext::Image.make_image_from_file(*args) do |src_file_path|
+              props = Utils.stringify_hash_key(props)
               args = [src_file_path, props, @output.canvas]
-              [Ext::AAFigure.make_image_by_aafigure(*args), props]
+              [Ext::AAFigure.make_image(*args), props]
+            end
+          end
+
+          def blockdiag(source, props={})
+            args = [@output.canvas, source]
+            Ext::Image.make_image_from_file(*args) do |src_file_path|
+              props = Utils.stringify_hash_key(props)
+              args = [src_file_path, props, @output.canvas]
+              [Ext::BlockDiag.make_image(*args), props]
+            end
+          end
+
+          def coderay(lang, source)
+            logger = @output.canvas.logger
+            Ext::CodeRay.highlight(lang, source, logger)
+          end
+
+          def emacs(source, mode_line=nil)
+            logger = @output.canvas.logger
+            Ext::Emacs.highlight(source, logger, mode_line)
+          end
+
+          def tag(name, value=nil)
+            if value
+              CustomTag.new(name, @output.text(value))
+            else
+              CustomTag.new(name)
             end
           end
         end
