@@ -6,12 +6,13 @@ proc_name = "slide-number"
 }
 
 @slide_number_color || nil
+@slide_number_position ||= :bottom
 
 match(Slide) do |slides|
   slides.delete_post_draw_proc_by_name(proc_name)
 
   break if @slide_number_uninstall
-  
+
   slides.add_post_draw_proc(proc_name) do |slide, canvas, x, y, w, h, simulation|
     unless simulation
       text = Text.new("#{slide.index}/#{canvas.slide_size - 1}")
@@ -20,8 +21,13 @@ match(Slide) do |slides|
       text.compile(canvas, x, y, w, h)
       layout = text.layout
       layout.set_width(w * Pango::SCALE)
-      num_y = canvas.height - @margin_bottom - text.height
-      canvas.draw_layout(text.layout, x, num_y, @slide_number_color)
+      case @slide_number_position
+      when :bottom
+        number_y = canvas.height - @margin_bottom - text.height
+      when :top
+        number_y = @margin_top
+      end
+      canvas.draw_layout(text.layout, x, number_y, @slide_number_color)
     end
     [x, y, w, h]
   end
